==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneHeaderConnectionEventArgsDescription, _super);
    function WebPaneHeaderConnectionEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebPaneHeaderConnectionEventArgsDescription.prototype.get_type = function () {
        return "WebPaneHeaderConnectionEventArgs";
    };
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebPaneHeaderConnectionEventArgsDescription.$t = markType(WebPaneHeaderConnectionEventArgsDescription, 'WebPaneHeaderConnectionEventArgsDescription', Description.$);
    return WebPaneHeaderConnectionEventArgsDescription;
}(Description));
export { WebPaneHeaderConnectionEventArgsDescription };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebPaneHeaderConnectionEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebPaneHeaderConnectionEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPaneHeaderConnectionEventArgsDescription, _super);
    function WebPaneHeaderConnectionEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.h = null;
        return _this;
    }
    WebPaneHeaderConnectionEventArgsDescription.prototype.get_type = function () {
        return "WebPaneHeaderConnectionEventArgs";
    };
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDescription.prototype, "pane", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Pane");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebPaneHeaderConnectionEventArgsDescription.prototype, "element", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Element");
        },
        enumerable: true,
        configurable: true
    });
    WebPaneHeaderConnectionEventArgsDescription.$t = markType(WebPaneHeaderConnectionEventArgsDescription, 'WebPaneHeaderConnectionEventArgsDescription', Description.$);
    return WebPaneHeaderConnectionEventArgsDescription;
}(Description));
export { WebPaneHeaderConnectionEventArgsDescription };
